package ru.ulstu.meeting;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;
import ru.ulstu.news.NewsService;

import javax.validation.constraints.NotNull;

@Service
public class MeetingService {
    private final MeetingRepository meetingRepository;
    private final NewsService newsService;

    public MeetingService(MeetingRepository meetingRepository,
                          NewsService newsService) {
        this.meetingRepository = meetingRepository;
        this.newsService = newsService;
    }

    public void create(Meeting meeting) {
        meetingRepository.save(meeting);
        newsService.create("Очередное заседание семинара", "Заседание семинара состоится " + meeting.getDate());
    }

    public void save(Meeting meeting) {
        if (meeting.getId() != null && (meeting.getId() != 0)) {
            meetingRepository.save(meeting);
        } else {
            create(meeting);
        }
    }

    public Meeting getById(@NotNull Integer id) {
        return meetingRepository
                .findById(id)
                .orElseThrow(() -> new RuntimeException("Запись о заседании не найдена"));
    }

    public void delete(Integer id) {
        meetingRepository.deleteById(id);
    }

    public Page<Meeting> getMeetings(Pageable pageable) {
        return meetingRepository.findByOrderByDateDesc(pageable);
    }
}
